# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List

from .category_resource_response import CategoryResourceResponse

__all__ = ["CategoryDeleteResponse"]

CategoryDeleteResponse = Dict[str, List[CategoryResourceResponse]]
